From cfc513043c5830b5a967733066068c7097b42e3c Mon Sep 17 00:00:00 2001
From: kenneth_suter <kenneth_suter@localhost>
Date: Wed, 15 Aug 2007 21:34:53 +0000
Subject: [PATCH] This commit is a step toward getting OpenDS internationalized. There are still issues to be resolved before we can declare that we are internationalized but this commit covers the bulk of changes needed at this time.
---
opendj-sdk/opends/src/server/org/opends/server/util/args/StringArgument.java | 21 +++++++++------------
1 files changed, 9 insertions(+), 12 deletions(-)
diff --git a/opendj-sdk/opends/src/server/org/opends/server/util/args/StringArgument.java b/opendj-sdk/opends/src/server/org/opends/server/util/args/StringArgument.java
index ed055f4..10881e8 100644
--- a/opendj-sdk/opends/src/server/org/opends/server/util/args/StringArgument.java
+++ b/opendj-sdk/opends/src/server/org/opends/server/util/args/StringArgument.java
@@ -25,7 +25,9 @@
* Portions Copyright 2006-2007 Sun Microsystems, Inc.
*/
package org.opends.server.util.args;
+import org.opends.messages.Message;
+import org.opends.messages.MessageBuilder;
/**
@@ -50,10 +52,8 @@
* be displayed in usage information, or
* <CODE>null</CODE> if this argument does not
* require a value.
* @param descriptionID The unique ID of the description for this
* argument.
- * @param descriptionArgs The arguments that are to be used when generating
- * the description for this argument.
*
* @throws ArgumentException If there is a problem with any of the
* parameters used to create this argument.
@@ -61,11 +61,11 @@
public StringArgument(String name, Character shortIdentifier,
String longIdentifier, boolean isRequired,
boolean needsValue, String valuePlaceholder,
- int descriptionID, Object... descriptionArgs)
+ Message description)
throws ArgumentException
{
super(name, shortIdentifier, longIdentifier, isRequired, false, needsValue,
- valuePlaceholder, null, null, descriptionID, descriptionArgs);
+ valuePlaceholder, null, null, description);
}
@@ -95,10 +95,8 @@
* @param propertyName The name of the property in a property file that
* may be used to override the default value but
* will be overridden by a command-line argument.
* @param descriptionID The unique ID of the description for this
* argument.
- * @param descriptionArgs The arguments that are to be used when generating
- * the description for this argument.
*
* @throws ArgumentException If there is a problem with any of the
* parameters used to create this argument.
@@ -107,13 +105,12 @@
String longIdentifier, boolean isRequired,
boolean isMultiValued, boolean needsValue,
String valuePlaceholder, String defaultValue,
- String propertyName, int descriptionID,
- Object... descriptionArgs)
+ String propertyName, Message description)
throws ArgumentException
{
super(name, shortIdentifier, longIdentifier, isRequired, isMultiValued,
needsValue, valuePlaceholder, defaultValue, propertyName,
- descriptionID, descriptionArgs);
+ description);
}
@@ -130,7 +127,7 @@
* <CODE>false</CODE> if it is not.
*/
public boolean valueIsAcceptable(String valueString,
- StringBuilder invalidReason)
+ MessageBuilder invalidReason)
{
// All values will be acceptable for this argument.
return true;
@@ -50,10 +52,8 @@
* <CODE>null</CODE> if this argument does not
* require a value.
- * @param descriptionID The unique ID of the description for this
+ * @param description Message for the description of this
* argument.
@@ -95,10 +95,8 @@
* may be used to override the default value but
* will be overridden by a command-line argument.
- * @param descriptionID The unique ID of the description for this
+ * @param description Message for the description of this
* argument.
--
Gitblit v1.10.0